@@ -113,7 +113,7 @@ GET.necdf <- function(x, r = seq(min(unlist((lapply(x, min)))), max(unlist((lapp
   if(!is.list(x) && length(x)<2) stop("At least two groups should be provided.")
   x.lengths <- as.numeric(lapply(x, FUN = length))
   if(!is.null(names(x))) groups <- rep(names(x), times=x.lengths)
-  else groups <- rep(1:length(x), times=x.lengths)
+  else groups <- rep(seq_along(x), times=x.lengths)
   groups <- factor(groups, levels=unique(groups))
   gnames <- levels(groups)
   if(missing(nsim)) {
@@ -136,7 +136,7 @@ GET.necdf <- function(x, r = seq(min(unlist((lapply(x, min)))), max(unlist((lapp
   sim <- replicate(nsim, fun(x, sample(groups, size=length(groups), replace=FALSE), r), simplify = "array")
   complabels <- colnames(obs)
 
-  csets <- list()
+  csets <- vector("list", ncol(obs))
   for(i in 1:ncol(obs)) {
     csets[[i]] <- create_curve_set(list(r = r,
                                         obs = obs[,i],
