@@ -7,7 +7,7 @@ matching <- function( X.randomized, long, lat, Delta, target_variog, prctile, id
   linear.fit <- variog.X.delta
   hat.X.delta <- variog.X.delta
   resid.sum.squares <- rep(0, length(Delta))
-  for(k in 1:length(Delta)) {
+  for(k in seq_along(Delta)) {
     # smooth X.randomized using locfit:
     fit <- locfit::locfit(X.randomized ~ locfit::lp(long, lat, nn = Delta[k], deg = 0), kern = "gauss", maxk = maxk)
     X.delta <- fitted(fit)
@@ -260,7 +260,7 @@ GET.localcor <- function(data, Delta, nsim = 1000, typeone = c("fdr", "fwer"),
     if(widthheight)
       res <- create_curve_set(list(r=data.frame(x=lat, y=long, width=d.x, height=d.y), obs=loc.cor.obs))
     else
-      res <- create_curve_set(list(r=1:length(lat), obs=loc.cor.obs))
+      res <- create_curve_set(list(r=seq_along(lat), obs=loc.cor.obs))
   }
   res
 }
