@@ -106,10 +106,10 @@ fdr_rejections_between_two_rank <- function(ind, ind_Robs, limit, curve_set,
     d <- max(0.0001, min(0.0075, nsim * limit / ( nr * mult )))
     gammas <- seq(0+d/2, 1-d/2, by=d)
     # Calculate rejections for each gamma
-    e <- list()
+    e <- vector("list", length(gammas))
     R.obs_new <- R0_new <- vector(length=length(gammas))
     if(is.null(llimit) & is.null(ulimit)) {
-      for(i in 1:length(gammas)) {
+      for(i in seq_along(gammas)) {
         if(alternative != "greater") LB <- e2$LB + log(gammas[i]) * (e2$UB - e2$LB) else LB <- -Inf
         if(alternative != "less") UB <- e2$UB - log(gammas[i]) * (e2$UB - e2$LB) else UB <- Inf
         R.obs_new[i] <- noutside(obs_curve, LB, UB, alternative)
@@ -118,7 +118,7 @@ fdr_rejections_between_two_rank <- function(ind, ind_Robs, limit, curve_set,
       }
     }
     else { # llimit or ulimit
-      for(i in 1:length(gammas)) {
+      for(i in seq_along(gammas)) {
         if(alternative != "greater") LB <- llimit + (gammas[i])*(e2$LB-llimit) else LB <- -Inf
         if(alternative != "less") UB <- ulimit - (gammas[i])*(ulimit-e2$UB) else UB <- Inf
         R.obs_new[i] <- noutside(obs_curve, LB, UB, alternative)
@@ -148,9 +148,9 @@ fdr_rejections_between_two_rank <- function(ind, ind_Robs, limit, curve_set,
     gammas <- seq(ind, ind+1, length=18)
     gammas <- gammas[-c(1, length(gammas))]
     # Calculate rejections for each gamma
-    e <- list()
+    e <- vector("list", length(gammas))
     R.obs_new <- R0_new <- vector(length=length(gammas))
-    for(i in 1:length(gammas)) {
+    for(i in seq_along(gammas)) {
       if(alternative != "greater") LB <- e1l + (gammas[i] - ind)*(e2l-e1l) else LB <- -Inf
       if(alternative != "less") UB <- e1u - (gammas[i] - ind)*(e1u-e2u) else UB <- Inf
       R.obs_new[i] <- noutside(obs_curve, LB, UB, alternative)
